@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2001, 2002, 2006 Philip Blundell <philb@gnu.org>
+ * Copyright (C) 2006 Neal H. Walfield <neal@walfield.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -11,57 +12,59 @@
 #include <time.h>
 #include <gpe/event-db.h>
 
-extern time_t viewtime;
-extern gboolean force_today;
+#include "util.h"
 
-extern void update_current_view (void);
-extern void update_all_views (void);
+#ifdef IS_HILDON
+#if HILDON_VER > 0
+#include <hildon/hildon-program.h>
+#else
+#include <hildon-widgets/hildon-program.h>
+#endif /* HILDON_VER  */
+#endif
 
-extern guint days_in_month (guint year, guint month);
-extern gboolean week_starts_monday;
+#define ERROR_DOMAIN() g_quark_from_static_string ("gpe-calendar")
+
+extern EventDB *event_db;
+
+extern gboolean week_starts_sunday;
 extern guint week_offset;
 extern gboolean day_view_combined_times;
-extern void set_time_and_day_view(time_t selected_time);
-extern void set_time_all_views(void);
-extern time_t time_from_day(int year, int month, int day);
+extern void set_time_and_day_view (time_t selected_time);
 
+#ifdef IS_HILDON
+#if HILDON_VER > 0
+  extern HildonWindow *main_window;
+#else
+  extern GtkWidget *main_window;
+#endif /* HILDON_VER  */
+#else
+  extern GtkWidget *main_window;
+#endif
 
-extern GdkPixmap *close_pix, *day_pix;
-extern GdkBitmap *close_mask, *day_mask;
-
-extern GtkWidget *main_window, *pop_window;
-
-extern GdkFont *yearfont, *datefont;
-extern gchar *strftime_strdup_utf8_locale (const char *fmt, struct tm *tm);
-extern gchar *strftime_strdup_utf8_utf8 (const char *fmt, struct tm *tm);
-extern guint day_of_week(guint year, guint month, guint day);
 
 #define SECONDS_IN_DAY (24*60*60)
 
-/* stuff that could perhaps be configurable */
-#define TIMEFMT "%R"
-#define MONTHTIMEFMT "%a %d"
+extern const gchar *TIMEFMT;
 
 /* Maemo's stupid application installer uses a wrong prefix, 
  * so we define the icon files here. */
 #ifdef IS_HILDON
-  #define INST_PREFIX  "/var/lib/install/usr/share/gpe/pixmaps/default/"
+  #define INST_PREFIX  "/usr/share/gpe/pixmaps/default/"
   #define DAY_ICON     INST_PREFIX "day_view.png"
   #define WEEK_ICON    INST_PREFIX "week_view.png"
   #define MONTH_ICON   INST_PREFIX "month_view.png"
+  #define FUTURE_ICON   INST_PREFIX "future_view.png"
   #define BELL_ICON    INST_PREFIX "bell.png"
   #define RECUR_ICON   INST_PREFIX "recur.png"
   #define BELLRECUR_ICON INST_PREFIX "bell_recur.png"
-  #define APP_ICON     "/var/lib/install/usr/share/pixmaps/gpe-calendar.png"
 #else
   #define DAY_ICON       "day_view"
   #define WEEK_ICON      "week_view"
   #define MONTH_ICON     "month_view"
+  #define FUTURE_ICON    "future_view"
   #define BELL_ICON      "bell"
   #define RECUR_ICON     "recur"
   #define BELLRECUR_ICON "bell_recur"
-  #define APP_ICON       PREFIX "/share/pixmaps/gpe-calendar.png"
 #endif
+#define APP_ICON       PREFIX "/share/pixmaps/gpe-calendar.png"
 
-#define get_cloned_ev(arg) \
-  ((arg->flags & FLAG_CLONE) ? (event_t)arg->cloned_ev : arg)
